Generator

Struct Generator 

pub struct Generator { /* private fields */ }
Generator is a main point of rust_swig. It expands rust macroses and generates not rust code. It designed to use inside build.rs.

Implementations

Source

impl Generator

pub fn new(config: LanguageConfig) -> Generator

pub fn with_pointer_target_width(self, pointer_target_width: usize) -> Self

By default we get pointer_target_width via cargo (more exactly CARGO_CFG_TARGET_POINTER_WIDTH), but you can change default value via this method

pub fn rustfmt_bindings(self, doit: bool) -> Self

Set whether rustfmt should format the generated bindings.

pub fn remove_not_generated_files_from_output_directory( self, doit: bool, ) -> Self

If true removes not generated by rust_swig files from output directory, suitable for removing obsolete files. Warning! May remove your files if turn on, so by default false

pub fn merge_type_map(self, id_of_code: &str, code: &str) -> Generator

Add new foreign langauge type <-> Rust mapping

pub fn expand<S, D>(self, crate_name: &str, src: S, dst: D)
where S: AsRef<Path>, D: AsRef<Path>,

process src and save result of macro expansion to dst

Panics

Panics on error